==> nateon-1.0.1.192.tar.bz2: nateon-1.0/nateon/network/nomhttpproxy.h <==
/***************************************************************************
 *   Copyright (C) 2008 by SK Communications.                              *
 *   http://kldp.net/projects/nateon/                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef NOMHTTPPROXY_H
#define NOMHTTPPROXY_H

#include <qobject.h>

class NOMHTTPProxy
{
public:
	NOMHTTPProxy( QString Host, unsigned int Port, unsigned int Ticket = 0 );
	~NOMHTTPProxy();
	void setTicket( unsigned int Ticket ) { nTicket = Ticket; }
	QString getHost() { return sHost; }
	unsigned int getPort() { return nPort; }
	unsigned int getTicket() { return nTicket; }
	
	QString getPOST( QString Command );

private:
	QString sHost;
	unsigned int nPort;
	unsigned int nTicket;
};

#endif

==> nateon-1.0.1.275.tar.bz2: nateon-1.0/nateon/network/nomhttpproxy.h <==
/***************************************************************************
 *   Copyright (C) 2008 by SK Communications.                              *
 *   http://kldp.net/projects/nateon/                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef NOMHTTPPROXY_H
#define NOMHTTPPROXY_H

#include <qobject.h>

class NOMHTTPProxy {
public:
    NOMHTTPProxy( QString Host, unsigned int Port, unsigned int Ticket = 0 );
    ~NOMHTTPProxy();
    void setTicket( unsigned int Ticket ) {
        nTicket = Ticket;
    }
    QString getHost() {
        return sHost;
    }
    unsigned int getPort() {
        return nPort;
    }
    unsigned int getTicket() {
        return nTicket;
    }

    QString getPOST( QString Command );

private:
    QString sHost;
    unsigned int nPort;
    unsigned int nTicket;
};

#endif
